import React, { memo, useCallback } from 'react';
import { Image, Pressable, StyleSheet } from 'react-native';
import { useCalendarContext } from '../../calendar-context';
import { YEAR_PAGE_SIZE } from '../../utils';
import { isEqual } from 'lodash';
import { ThemedView } from '../../ui';
import { COLORS } from '../../theme';
import { useColorScheme } from 'nativewind';
const arrow_left = require('../../assets/images/arrow_left.png');
const PrevButton = ({
  style,
  className
}) => {
  const {
    currentYear,
    calendarView,
    onChangeMonth,
    onChangeYear,
    components
  } = useCalendarContext();
  const {
    colorScheme
  } = useColorScheme();
  const theme = colorScheme ?? 'light';
  const onPress = useCallback(() => {
    switch (calendarView) {
      case 'day':
        return onChangeMonth(-1);
      case 'month':
        return onChangeYear(currentYear - 1);
      case 'year':
        return onChangeYear(currentYear - YEAR_PAGE_SIZE);
      default:
        return {};
    }
  }, [calendarView, currentYear, onChangeMonth, onChangeYear]);
  return /*#__PURE__*/React.createElement(Pressable, {
    disabled: calendarView === 'time',
    onPress: onPress,
    testID: "btn-prev",
    accessibilityRole: "button",
    accessibilityLabel: "Prev"
  }, /*#__PURE__*/React.createElement(ThemedView, {
    style: [defaultStyles.iconContainer, defaultStyles.prev, style],
    className: className
  }, (components === null || components === void 0 ? void 0 : components.PrevIcon) || /*#__PURE__*/React.createElement(Image, {
    source: arrow_left,
    tintColor: COLORS[theme].foreground,
    style: {
      width: 14,
      height: 14
    }
  })));
};
const customComparator = (prev, next) => {
  const areEqual = prev.className === next.className && isEqual(prev.style, next.style);
  return areEqual;
};
export default /*#__PURE__*/memo(PrevButton, customComparator);
const defaultStyles = StyleSheet.create({
  iconContainer: {
    padding: 4
  },
  prev: {
    marginRight: 3
  }
});
//# sourceMappingURL=prev-button.js.map